package com.engine.attendance.web;

import com.engine.common.util.ParamUtil;
import com.engine.common.util.ServiceUtil;
import com.engine.attendance.service.WorkRulesService;
import com.engine.attendance.service.impl.WorkRulesServiceImpl;
import com.engine.attendance.util.ResponseResult;
import weaver.hrm.HrmUserVarify;
import weaver.hrm.User;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import java.util.Map;

/**
 * @Author liang.cheng
 * @Date 2023/12/26 6:52 PM
 * @Description: 标准组件示例代码
 * @Version 1.0
 */
public class WorkRulesController {

    private WorkRulesService getReportCollectService(User user) {
        return ServiceUtil.getService(WorkRulesServiceImpl.class,user);
    }


    /**
     * @Description: 方案一 Table
     * @Author: liang.cheng
     * @Date: 2024/1/15 4:25 PM
     * @param: [request, response, resourceIds]
     * @return: java.lang.String
     */
    @GET
    @Path("/list")
    @Produces(MediaType.APPLICATION_JSON)
    public String getWorkRulesList(@Context HttpServletRequest request, @Context HttpServletResponse response,
                                    @QueryParam("resourceIds") String resourceIds) {
        User user = HrmUserVarify.getUser(request, response);
        return new ResponseResult<String, Map<String, Object>>(user).run(getReportCollectService(user) :: getWorkRulesList,resourceIds);
    }

    /**
     * @Description: 方案二 Table 注解形式
     * @Author: liang.cheng
     * @Date: 2024/1/15 4:27 PM
     * @param: [request, response]
     * @return: com.engine.organization.util.response.ReturnResult
     */
    @GET
    @Path("/getTable")
    @Produces(MediaType.APPLICATION_JSON)
    public String listScheme(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        User user = HrmUserVarify.getUser(request, response);
        Map<String, Object> map = ParamUtil.request2Map(request);
        return new ResponseResult< Map<String, Object>, Map<String, Object>>(user).run(getReportCollectService(user) :: getWorkRulesList1,map);
    }


    /**
     * @Description: 高级搜索 表单等标准组件返回格式
     * @Author: liang.cheng
     * @Date: 2024/1/15 4:44 PM
     * @param: [request, response]
     * @return: java.lang.String
     */
    @GET
    @Path("/getSchemeForm")
    @Produces(MediaType.APPLICATION_JSON)
    public String getSchemeForm(@Context HttpServletRequest request, @Context HttpServletResponse response) {
        User user = HrmUserVarify.getUser(request, response);
        Map<String, Object> map = ParamUtil.request2Map(request);
        return new ResponseResult< Map<String, Object>, Map<String, Object>>(user).run(getReportCollectService(user) :: getSchemeForm,map);
    }



}
